/* Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.portlet.faces.application;

import java.util.Collection;
import java.util.Iterator;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.el.ELContextListener;
import javax.el.ELException;
import javax.el.ELResolver;
import javax.el.ExpressionFactory;
import javax.el.ValueExpression;

import javax.faces.FacesException;
import javax.faces.application.Application;
import javax.faces.application.ApplicationWrapper;
import javax.faces.component.UIComponent;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;

import javax.portlet.faces.BridgeUtil;
import javax.portlet.faces.annotation.PortletNamingContainer;
import javax.portlet.faces.component.PortletNamingContainerUIViewRoot;


public class PortletApplicationImpl extends ApplicationWrapper
{
  private Application mWrapped;

  public PortletApplicationImpl(Application app)
  {
    mWrapped = app;
  }

  /**
   * Create a new UIComponent subclass, using the mappings defined by previous
   * calls to the addComponent method of this class.
   * <p>
   * @throws FacesException if there is no mapping defined for the specified
   * componentType, or if an instance of the specified type could not be
   * created for any reason.
   */
  public javax.faces.component.UIComponent createComponent(String componentType)
    throws FacesException
  {
    UIComponent component = getWrapped().createComponent(componentType);
    if (BridgeUtil.isPortletRequest() &&
        component.getClass() == UIViewRoot.class &&
        UIViewRoot.class.getAnnotation(PortletNamingContainer.class) ==
        null)
    {
      // replace with our own UIViewRoot
      component = new PortletNamingContainerUIViewRoot();
    }
    return component;
  }
  
  public Application getWrapped()
  {
    return mWrapped;
  }
}
