/* Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.portlet.faces.application;


import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.StringWriter;

import java.util.Map;

import java.util.concurrent.ConcurrentHashMap;

import javax.faces.FacesException;
import javax.faces.application.StateManager;
import javax.faces.application.StateManagerWrapper;
import javax.faces.component.UIComponent;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;

import javax.faces.render.ResponseStateManager;

import javax.portlet.faces.Bridge;
import javax.portlet.faces.BridgeUtil;

import org.apache.myfaces.portlet.faces.bridge.BridgeImpl;

public class PortletResponseStateManagerImpl
  extends ResponseStateManager
{
  private ResponseStateManager mDelegatee = null;

  public PortletResponseStateManagerImpl(ResponseStateManager rsm)
  {
    mDelegatee = rsm;

  }
  
  public Object getComponentStateToRestore(FacesContext context)
  {
    return mDelegatee.getComponentStateToRestore(context);
  }
  
  public Object getState(FacesContext context, String viewId)
  {
    FacesContext ctx = FacesContext.getCurrentInstance();
    
    if (BridgeUtil.getPortletRequestPhase() == Bridge.PortletPhase.RENDER_PHASE && 
        ctx.getExternalContext().getRequestMap().get(BridgeImpl.SAVED_VIEW_STATE) != null)
    {
      // don't remove in case we are called again in this request. -- it will get removed from the
      // bridge request scope later (after the save) to avoid its reuse
      return ctx.getExternalContext().getRequestMap().get(BridgeImpl.SAVED_VIEW_STATE);
    }
    else
    {
      return mDelegatee.getState(context, viewId); 
    }
  }

  public Object getTreeStructureToRestore(FacesContext context,
                                          String viewId)
  {
    return mDelegatee.getTreeStructureToRestore(context, viewId);
  }
  
  public String getViewState(FacesContext context,
                             Object state)
  {
    return mDelegatee.getViewState(context, state); 
  }
  
  public boolean isPostback(FacesContext context)
  {
    return mDelegatee.isPostback(context);
  }
  
  public void writeState(FacesContext context, Object state) throws IOException
  {
    mDelegatee.writeState(context, state);
    return;
  }
  
  public void writeState(FacesContext context, StateManager.SerializedView state) throws IOException
  {
    mDelegatee.writeState(context, state);
    return;
  }
}
