/* Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.portlet.faces.context;

import javax.faces.context.PartialViewContextFactory;
import javax.faces.context.PartialViewContext;
import javax.faces.context.FacesContext;
import javax.faces.context.FacesContextFactory;

/**
 * <p>
 * Factory to vend extension to the default <code>PartialViewContext</code> instance.
 * Its exists so the bridge can modify execute/render ids to be true clientIds:\
 *     issue caused because developers may provide a specific id in html and then reference
 *     in there javascript -- because the bridge adds a namespace these aren't the true ids
 *     however because they are explictly named by developer they are what is passed.  The
 *     bridge needs to convert these "ids" to "clientids"
 * </p>
 */
public class PortletPartialViewContextFactoryImpl extends PartialViewContextFactory
{
  
  private PartialViewContextFactory mFactory;
  
  public PortletPartialViewContextFactoryImpl(PartialViewContextFactory factory)
  {
    mFactory = factory;
  }
  
  @Override
  public PartialViewContextFactory getWrapped()
  {
    return mFactory;
  }


    // ---------------------------------- Methods from PartialViewContextFactory


    /**
     * @see PartialViewContextFactory#getPartialViewContext(javax.faces.context.FacesContext)
     */
    public PartialViewContext getPartialViewContext(FacesContext context) {

        return new PortletPartialViewContextImpl(getWrapped().getPartialViewContext(context));

    }
    
}
